@@ -132,6 +132,24 @@ class TestValidate(TestCase):
         with self.assertRaises(BadConfigurationError) as context:
             df, msg = v.validate(df, val_dict)
 
+        # Test dates
+
+        dates = []
+        for i in range(10):
+            dates.append(f'2022-01-{i + 1}')
+        df = pd.DataFrame({'dates': dates})
+        df.loc[:,'dates'] = pd.to_datetime(df.loc[:,'dates'])
+        val_dict = [
+            {'col': 'dates', 'min_date': '2022-01-02', 'max_date': '2022-01-05', 'max_date_offset': 2,
+             'tz': None, 'action': 'null'}
+        ]
+        df, msg = v.validate(df, val_dict)
+        self.assertTrue(pd.isna(df.loc[0, 'dates']))
+        self.assertTrue(pd.isna(df.loc[5, 'dates']))
+        self.assertEqual(datetime(2022,1,5), df.loc[4, 'dates'])
+
+
+
     def test__apply_action(self):
         v = Validate(verbose=True)
         # action = ['raise', 'print', 'trim', 'null']
@@ -176,8 +194,8 @@ class TestValidate(TestCase):
         max_date = datetime(2022, 1, 3)
         timezone_str = None
         mask = v._validate_date(series, None, max_date, None, None, timezone_str, '0')
-        self.assertTrue(mask[0])
-        self.assertFalse(mask[3])
+        self.assertFalse(mask[0])
+        self.assertTrue(mask[3])
 
         # unit test to check if time zone aware series is passed
         dates = []
@@ -187,8 +205,8 @@ class TestValidate(TestCase):
         max_date = datetime(2022, 1, 3)
         timezone_str = 'US/Central'
         mask = v._validate_date(series, None, max_date, None, None, timezone_str, '0')
-        self.assertTrue(mask[0])
-        self.assertFalse(mask[3])
+        self.assertFalse(mask[0])
+        self.assertTrue(mask[3])
 
         # Check relative dates
         dates = []
@@ -200,8 +218,8 @@ class TestValidate(TestCase):
         max_date = 'tomorrow'
         timezone_str = None
         mask = v._validate_date(series, None, max_date, None, None, timezone_str, '0')
-        self.assertTrue(mask[0])
-        self.assertFalse(mask[2])
+        self.assertFalse(mask[0])
+        self.assertTrue(mask[2])
 
         # Check relative dates with an offset
         dates = []
@@ -214,8 +232,8 @@ class TestValidate(TestCase):
         max_offset = -1
         timezone_str = None
         mask = v._validate_date(series, None, max_date, None, max_offset, timezone_str, '0')
-        self.assertTrue(mask[0])
-        self.assertFalse(mask[2])
+        self.assertFalse(mask[0])
+        self.assertTrue(mask[2])
 
         # ****************
         # Check min dates
@@ -228,8 +246,8 @@ class TestValidate(TestCase):
         min_date = datetime(2022, 1, 3)
         timezone_str = None
         mask = v._validate_date(series, min_date, None, None, None, timezone_str, '0')
-        self.assertFalse(mask[0])
-        self.assertTrue(mask[3])
+        self.assertTrue(mask[0])
+        self.assertFalse(mask[3])
 
         # unit test to check if time zone aware series is passed
         dates = []
@@ -239,8 +257,8 @@ class TestValidate(TestCase):
         min_date = datetime(2022, 1, 3)
         timezone_str = 'US/Central'
         mask = v._validate_date(series, min_date, None, None, None, timezone_str, '0')
-        self.assertFalse(mask[0])
-        self.assertTrue(mask[2])
+        self.assertTrue(mask[0])
+        self.assertFalse(mask[3])
 
         # Check relative dates
         dates = []
@@ -252,8 +270,8 @@ class TestValidate(TestCase):
         min_date = 'tomorrow'
         timezone_str = None
         mask = v._validate_date(series, min_date, None, None, None, timezone_str, '0')
-        self.assertFalse(mask[0])
-        self.assertTrue(mask[2])
+        self.assertTrue(mask[0])
+        self.assertFalse(mask[2])
 
         # Check relative dates with an offset
         dates = []
@@ -266,8 +284,8 @@ class TestValidate(TestCase):
         min_offset = 2
         timezone_str = None
         mask = v._validate_date(series, min_date, None, min_offset, None, timezone_str, '0')
-        self.assertFalse(mask[0])
-        self.assertTrue(mask[2])
+        self.assertTrue(mask[0])
+        self.assertFalse(mask[2])
 
         # ****************
         # Check min and max dates
@@ -281,11 +299,11 @@ class TestValidate(TestCase):
         max_date = "2022-01-03"
         timezone_str = None
         mask = v._validate_date(series, min_date, max_date, None, None, timezone_str, '0')
-        self.assertFalse(mask[0])
-        self.assertTrue(mask[1])
-        self.assertTrue(mask[2])
-        self.assertFalse(mask[3])
-        self.assertFalse(mask[4])
+        self.assertTrue(mask[0])
+        self.assertFalse(mask[1])
+        self.assertFalse(mask[2])
+        self.assertTrue(mask[3])
+        self.assertTrue(mask[4])
 
         # ****************
         # Check non datetime column
